summaryrefslogtreecommitdiff
path: root/indra/llprimitive/llprimitive.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'indra/llprimitive/llprimitive.cpp')
-rwxr-xr-xindra/llprimitive/llprimitive.cpp31
1 files changed, 15 insertions, 16 deletions
diff --git a/indra/llprimitive/llprimitive.cpp b/indra/llprimitive/llprimitive.cpp
index 2fa77177f5..a505ea04a7 100755
--- a/indra/llprimitive/llprimitive.cpp
+++ b/indra/llprimitive/llprimitive.cpp
@@ -38,7 +38,6 @@
#include "lldatapacker.h"
#include "llsdutil_math.h"
#include "llprimtexturelist.h"
-#include "imageids.h"
#include "llmaterialid.h"
/**
@@ -127,7 +126,7 @@ void LLPrimitive::setVolumeManager( LLVolumeMgr* volume_manager )
{
if ( !volume_manager || sVolumeManager )
{
- llerrs << "LLPrimitive::sVolumeManager attempting to be set to NULL or it already has been set." << llendl;
+ LL_ERRS() << "LLPrimitive::sVolumeManager attempting to be set to NULL or it already has been set." << LL_ENDL;
}
sVolumeManager = volume_manager;
}
@@ -198,7 +197,7 @@ LLPrimitive *LLPrimitive::createPrimitive(LLPCode p_code)
}
else
{
- llerrs << "primitive allocation failed" << llendl;
+ LL_ERRS() << "primitive allocation failed" << LL_ENDL;
}
return retval;
@@ -484,7 +483,7 @@ LLPCode LLPrimitive::legacyToPCode(const U8 legacy)
pcode = LL_PCODE_TREE_NEW;
break;
default:
- llwarns << "Unknown legacy code " << legacy << " [" << (S32)legacy << "]!" << llendl;
+ LL_WARNS() << "Unknown legacy code " << legacy << " [" << (S32)legacy << "]!" << LL_ENDL;
}
return pcode;
@@ -579,7 +578,7 @@ U8 LLPrimitive::pCodeToLegacy(const LLPCode pcode)
legacy = TREE_NEW;
break;
default:
- llwarns << "Unknown pcode " << (S32)pcode << ":" << pcode << "!" << llendl;
+ LL_WARNS() << "Unknown pcode " << (S32)pcode << ":" << pcode << "!" << LL_ENDL;
return 0;
}
return legacy;
@@ -587,7 +586,7 @@ U8 LLPrimitive::pCodeToLegacy(const LLPCode pcode)
// static
// Don't crash or llerrs here! This function is used for debug strings.
std::string LLPrimitive::pCodeToString(const LLPCode pcode)
{
std::string pcode_string;
@@ -666,7 +665,7 @@ std::string LLPrimitive::pCodeToString(const LLPCode pcode)
}
else
{
- llwarns << "Unknown base mask for pcode: " << base_code << llendl;
+ LL_WARNS() << "Unknown base mask for pcode: " << base_code << LL_ENDL;
}
U8 mask_code = pcode & (~LL_PCODE_BASE_MASK);
@@ -702,7 +701,7 @@ void LLPrimitive::copyTEs(const LLPrimitive *primitivep)
U32 i;
if (primitivep->getExpectedNumTEs() != getExpectedNumTEs())
{
- llwarns << "Primitives don't have same expected number of TE's" << llendl;
+ LL_WARNS() << "Primitives don't have same expected number of TE's" << LL_ENDL;
}
U32 num_tes = llmin(primitivep->getExpectedNumTEs(), getExpectedNumTEs());
if (mTextureList.size() < getExpectedNumTEs())
@@ -804,7 +803,7 @@ BOOL LLPrimitive::setVolume(const LLVolumeParams &volume_params, const S32 detai
{
S32 te_index = face_index_from_id(cur_mask, old_faces);
old_tes.copyTexture(face_bit, *(getTE(te_index)));
- //llinfos << face_bit << ":" << te_index << ":" << old_tes[face_bit].getID() << llendl;
+ //LL_INFOS() << face_bit << ":" << te_index << ":" << old_tes[face_bit].getID() << LL_ENDL;
}
}
@@ -824,7 +823,7 @@ BOOL LLPrimitive::setVolume(const LLVolumeParams &volume_params, const S32 detai
if (mVolumep->getNumFaces() == 0 && new_face_mask != 0)
{
- llwarns << "Object with 0 faces found...INCORRECT!" << llendl;
+ LL_WARNS() << "Object with 0 faces found...INCORRECT!" << LL_ENDL;
setNumTEs(mVolumep->getNumFaces());
return TRUE;
}
@@ -882,7 +881,7 @@ BOOL LLPrimitive::setVolume(const LLVolumeParams &volume_params, const S32 detai
}
if (i == 4)
{
- llwarns << "No path end or outer face in volume!" << llendl;
+ LL_WARNS() << "No path end or outer face in volume!" << LL_ENDL;
}
continue;
}
@@ -918,7 +917,7 @@ BOOL LLPrimitive::setVolume(const LLVolumeParams &volume_params, const S32 detai
}
if (i == 4)
{
- llwarns << "No path end or outer face in volume!" << llendl;
+ LL_WARNS() << "No path end or outer face in volume!" << LL_ENDL;
}
continue;
}
@@ -944,8 +943,8 @@ BOOL LLPrimitive::setVolume(const LLVolumeParams &volume_params, const S32 detai
}
if (-1 == min_outer_bit)
{
- llinfos << (LLVolume *)mVolumep << llendl;
- llwarns << "Bad! No outer faces, impossible!" << llendl;
+ LL_INFOS() << (LLVolume *)mVolumep << LL_ENDL;
+ LL_WARNS() << "Bad! No outer faces, impossible!" << LL_ENDL;
}
face_mapping[face_bit] = min_outer_bit;
}
@@ -964,7 +963,7 @@ BOOL LLPrimitive::setVolume(const LLVolumeParams &volume_params, const S32 detai
{
if (-1 == face_mapping[face_bit])
{
- llwarns << "No mapping from old face to new face!" << llendl;
+ LL_WARNS() << "No mapping from old face to new face!" << LL_ENDL;
}
S32 te_num = face_index_from_id(cur_mask, mVolumep->getProfile().mFaces);
@@ -1422,7 +1421,7 @@ S32 LLPrimitive::unpackTEMessage(LLDataPacker &dp)
if (!dp.unpackBinaryData(packed_buffer, size, "TextureEntry"))
{
retval = TEM_INVALID;
- llwarns << "Bad texture entry block! Abort!" << llendl;
+ LL_WARNS() << "Bad texture entry block! Abort!" << LL_ENDL;
return retval;
}
@@ -587,7 +586,7 @@ U8 LLPrimitive::pCodeToLegacy(const LLPCode pcode)
// static
-// Don't crash or llerrs here! This function is used for debug strings.
+// Don't crash or LL_ERRS() here! This function is used for debug strings.
std::string LLPrimitive::pCodeToString(const LLPCode pcode)
{